@@ -311,9 +311,33 @@ drawable_get_adjusted_size (EelBackground *self,
 {
     if (self->details->is_desktop)
     {
+#if GTK_CHECK_VERSION (3, 22, 0)
+        GdkRectangle geometry;
+        GdkMonitor  *monitor;
+        GdkDisplay  *display;
+        int n = 0;
+        int i = 0;
+        int sc_width = 0;
+        int sc_height = 0;
+
+        display = gtk_widget_get_display (self->details->widget);
+        n = gdk_display_get_n_monitors (display);
+
+        for (i = 0; i < n; ++i)
+        {
+            monitor = gdk_display_get_monitor (display, i);
+            gdk_monitor_get_geometry (monitor, &geometry);
+            sc_width = sc_width + geometry.width;
+            sc_height = sc_height + geometry.height;
+        }
+
+        *width = sc_width;
+        *height = sc_height;
+#else
         GdkScreen *screen = gtk_widget_get_screen (self->details->widget);
         *width = gdk_screen_get_width (screen);
         *height = gdk_screen_get_height (screen);
+#endif
     }
     else
     {
@@ -937,7 +961,12 @@ eel_background_is_dark (EelBackground *self)
 
     /* only check for the background on the 0th monitor */
     GdkScreen *screen = gdk_screen_get_default ();
+#if GTK_CHECK_VERSION (3, 22, 0)
+    GdkDisplay *display = gdk_screen_get_display (screen);
+    gdk_monitor_get_geometry (gdk_display_get_monitor (display, 0), &rect);
+#else
     gdk_screen_get_monitor_geometry (screen, 0, &rect);
+#endif
 
     return mate_bg_is_dark (self->details->bg, rect.width, rect.height);
 }
