@@ -144,9 +144,15 @@ caja_bookmarks_window_response_callback (GtkDialog *dialog,
     {
         GError *error = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+        gtk_show_uri_on_window (GTK_WINDOW (dialog),
+                                "help:mate-user-guide/goscaja-36",
+                                gtk_get_current_event_time (), &error);
+#else
         gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (dialog)),
                       "help:mate-user-guide/goscaja-36",
                       gtk_get_current_event_time (), &error);
+#endif
 
         if (error)
         {
