@@ -32,10 +32,6 @@
 #include "caja-desktop-window.h"
 #include <glib/gi18n.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
-
 struct _CajaLocationDialogDetails
 {
     GtkWidget *entry;
@@ -98,9 +94,15 @@ response_callback (CajaLocationDialog *dialog,
         break;
     case GTK_RESPONSE_HELP :
         error = NULL;
+#if GTK_CHECK_VERSION (3, 22, 0)
+        gtk_show_uri_on_window (GTK_WINDOW (dialog),
+                                "help:mate-user-guide/caja-open-location",
+                                gtk_get_current_event_time (), &error);
+#else
         gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (dialog)),
                       "help:mate-user-guide/caja-open-location",
                       gtk_get_current_event_time (), &error);
+#endif
         if (error)
         {
             eel_show_error_dialog (_("There was an error displaying help."), error->message,
@@ -164,7 +166,7 @@ caja_location_dialog_init (CajaLocationDialog *dialog)
     gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
     gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
 
-    box = gtk_hbox_new (FALSE, 12);
+    box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_container_set_border_width (GTK_CONTAINER (box), 5);
     gtk_widget_show (box);
 
