@@ -1654,9 +1654,15 @@ help_button_callback (GtkWidget *widget, GtkWidget *property_browser)
     GError *error = NULL;
     GtkWidget *dialog;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+    gtk_show_uri_on_window (GTK_WINDOW (property_browser),
+                            "help:mate-user-guide/goscaja-50",
+                            gtk_get_current_event_time (), &error);
+#else
     gtk_show_uri (gtk_widget_get_screen (property_browser),
                   "help:mate-user-guide/goscaja-50",
                   gtk_get_current_event_time (), &error);
+#endif
 
     if (error)
     {
@@ -2189,6 +2195,8 @@ caja_property_browser_update_contents (CajaPropertyBrowser *property_browser)
     /* allocate a new container, with a scrollwindow and viewport */
     property_browser->details->content_frame = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_set_vexpand (property_browser->details->content_frame, TRUE);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (property_browser->details->content_frame),
+                                         GTK_SHADOW_IN);
     viewport = gtk_viewport_new (NULL, NULL);
     gtk_widget_show(viewport);
     gtk_viewport_set_shadow_type(GTK_VIEWPORT(viewport), GTK_SHADOW_IN);
