@@ -516,7 +516,12 @@ caja_window_zoom_to_default (CajaWindow *window)
 static guint
 get_max_forced_height (GdkScreen *screen)
 {
-    return (gdk_screen_get_height (screen) * 90) / 100;
+    gint height;
+
+    gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+                             NULL, &height);
+
+    return (height * 90) / 100;
 }
 
 /* Code should never force the window wider than this size.
@@ -525,7 +530,12 @@ get_max_forced_height (GdkScreen *screen)
 static guint
 get_max_forced_width (GdkScreen *screen)
 {
-    return (gdk_screen_get_width (screen) * 90) / 100;
+    gint width;
+
+    gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+                             &width, NULL);
+
+    return (width * 90) / 100;
 }
 
 /* This must be called when construction of CajaWindow is finished,
